"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.resolveVideoConfig = void 0;
const input_props_js_1 = require("./config/input-props.js");
const get_environment_js_1 = require("./get-environment.js");
const validate_dimensions_js_1 = require("./validation/validate-dimensions.js");
const validate_duration_in_frames_js_1 = require("./validation/validate-duration-in-frames.js");
const resolveVideoConfig = ({ composition, editorProps: editorPropsOrUndefined, signal, }) => {
    var _a, _b, _c, _d, _e, _f;
    const calculatedProm = composition.calculateMetadata
        ? composition.calculateMetadata({
            defaultProps: (_a = composition.defaultProps) !== null && _a !== void 0 ? _a : {},
            props: {
                ...((_b = composition.defaultProps) !== null && _b !== void 0 ? _b : {}),
                ...(editorPropsOrUndefined !== null && editorPropsOrUndefined !== void 0 ? editorPropsOrUndefined : {}),
                ...(typeof window === 'undefined' ||
                    (0, get_environment_js_1.getRemotionEnvironment)() === 'player-development' ||
                    (0, get_environment_js_1.getRemotionEnvironment)() === 'player-production'
                    ? {}
                    : (_c = (0, input_props_js_1.getInputProps)()) !== null && _c !== void 0 ? _c : {}),
            },
            abortSignal: signal,
        })
        : null;
    if (calculatedProm !== null &&
        typeof calculatedProm === 'object' &&
        'then' in calculatedProm) {
        return calculatedProm.then((c) => {
            var _a, _b;
            const { height, width, durationInFrames, fps } = validateCalculated({
                calculated: c,
                composition,
            });
            return {
                width,
                height,
                fps,
                durationInFrames,
                id: composition.id,
                defaultProps: (_b = (_a = c.props) !== null && _a !== void 0 ? _a : composition.defaultProps) !== null && _b !== void 0 ? _b : {},
            };
        });
    }
    const data = validateCalculated({
        calculated: calculatedProm,
        composition,
    });
    if (calculatedProm === null) {
        return {
            ...data,
            id: composition.id,
            defaultProps: (_d = composition === null || composition === void 0 ? void 0 : composition.defaultProps) !== null && _d !== void 0 ? _d : {},
        };
    }
    return {
        ...data,
        id: composition.id,
        defaultProps: (_f = (_e = calculatedProm === null || calculatedProm === void 0 ? void 0 : calculatedProm.props) !== null && _e !== void 0 ? _e : composition.defaultProps) !== null && _f !== void 0 ? _f : {},
    };
};
exports.resolveVideoConfig = resolveVideoConfig;
const validateCalculated = ({ composition, calculated, }) => {
    var _a, _b, _c, _d, _e, _f, _g, _h;
    const potentialErrorLocation = `calculated by calculateMetadata() for the composition "${composition.id}"`;
    const width = (_b = (_a = calculated === null || calculated === void 0 ? void 0 : calculated.width) !== null && _a !== void 0 ? _a : composition.width) !== null && _b !== void 0 ? _b : null;
    if (!width) {
        throw new TypeError('Composition width was neither specified via the `width` prop nor the `calculateMetadata()` function.');
    }
    (0, validate_dimensions_js_1.validateDimension)(width, 'width', potentialErrorLocation);
    const height = (_d = (_c = calculated === null || calculated === void 0 ? void 0 : calculated.height) !== null && _c !== void 0 ? _c : composition.height) !== null && _d !== void 0 ? _d : null;
    if (!height) {
        throw new TypeError('Composition height was neither specified via the `height` prop nor the `calculateMetadata()` function.');
    }
    (0, validate_dimensions_js_1.validateDimension)(width, 'height', potentialErrorLocation);
    const fps = (_f = (_e = calculated === null || calculated === void 0 ? void 0 : calculated.fps) !== null && _e !== void 0 ? _e : composition.fps) !== null && _f !== void 0 ? _f : null;
    if (!fps) {
        throw new TypeError('Composition fps was neither specified via the `fps` prop nor the `calculateMetadata()` function.');
    }
    const durationInFrames = (_h = (_g = calculated === null || calculated === void 0 ? void 0 : calculated.durationInFrames) !== null && _g !== void 0 ? _g : composition.durationInFrames) !== null && _h !== void 0 ? _h : null;
    if (!durationInFrames) {
        throw new TypeError('Composition durationInFrames was neither specified via the `durationInFrames` prop nor the `calculateMetadata()` function.');
    }
    (0, validate_duration_in_frames_js_1.validateDurationInFrames)({
        durationInFrames,
        component: potentialErrorLocation,
        allowFloats: false,
    });
    return { width, height, fps, durationInFrames };
};
